import React, { useState, useEffect, useCallback, useRef } from 'react';
import { FormattedMessage, history, useModel } from 'umi';
import { Spin, Popover, Dropdown, MenuProps } from 'antd';
import styles from './index.less';
import cx from 'classnames';
import PageHeader from '@/sagacare_components/PageHeader';
import Search from '@/sagacare_components/Search';
import Table from '@/sagacare_components/Table';
import Empty from './components/Empty';
import PersonModal from './components/personModal';
import { EllipsisOutlined } from '@ant-design/icons';

import {
  queryUserList,
  queryCompanyOAById,
  getControlSpaceCompany,
} from '@/services/sagacare_service/member';

const Member: React.FC = () => {
  const [perVisible, setPerVisible] = useState(false);
  const [isSyncOa, setIsSyncOa] = useState(false);
  const [userList, setUserList] = useState<any>([]);
  const [total, setTotal] = useState(10);
  const [loading, setLoading] = useState(false);
  const [page, setPage] = useState({
    pageNum: 1,
    pageSize: 10,
  });
  const [checkUser, setCheckUser] = useState({});
  const [checkSign, setCheckSign] = useState('add');

  const getColumns = () => {
    return [
      {
        title: '姓名',
        dataIndex: 'name',
      },
      {
        title: '类型',
        dataIndex: 'manageUserType',
        filteredValue: [],
        single: true,
        filters: [
          { value: '1', label: '正式成员' },
          { value: '2', label: '临时成员' },
          { value: '3', label: '管理员' },
        ],
      },
      {
        title: '手机号',
        dataIndex: 'phone',
      },
      {
        title: '职务',
        dataIndex: 'job',
      },
      {
        title: '常驻工区',
        dataIndex: 'permanentSpaceName',
      },
      {
        title: '可控工区',
        dataIndex: 'isAllControl',
        render: function (content, item, index) {
          return <span>{content ? '部分可控' : '全部可控'}</span>;
        },
      },
      {
        title: '更新时间',
        dataIndex: 'updateDate',
        sorter: true,
        sortered: 'DESC',
      },
      {
        title: '状态',
        dataIndex: 'status',
        render: function (content, item, index) {
          return (
            <div>
              <span className={styles.circle}></span>
              <span>{content}</span>
            </div>
          );
        },
      },
      {
        title: '',
        dataIndex: '',
        render: function (content, item) {
          const menuItems: MenuProps['items'] = [
            {
              key: '1',
              label: (
                <div
                  className={styles.operateLi}
                  onClick={() => {
                    checkPerson(item);
                  }}
                >
                  查看
                </div>
              ),
            },
            {
              key: '2',
              label: (
                <div
                  className={styles.operateLi}
                  onClick={() => {
                    editPerson(item);
                  }}
                >
                  编辑
                </div>
              ),
            },
            {
              key: '3',
              label: (
                <div
                  className={cx(styles.operateLi, { [styles.disabled]: item.oaId })}
                  onClick={() => {
                    invalidPerson(item);
                  }}
                >
                  作废
                </div>
              ),
            },
          ];
          return (
            <Dropdown menu={{ items: menuItems }}>
              <EllipsisOutlined />
            </Dropdown>
          );
        },
      },
    ];
  };
  const goToInvalid = () => {
    history.push(`/member/invalid`);
  };
  const onClose = () => {
    setPerVisible(false);
  };
  useEffect(() => {
    var paramObj = {
      criteria: {
        // param: 'string',
        // status: 0,
        companyId: '',
      },
      page: 0,
      size: 10,
      orders: [
        {
          column: '',
          asc: true,
        },
      ],
    };
    setUserList([
      {
        userId: '222',
        companyId: '222',
        companyName: '博锐',
        name: '赵女士',
        phone: '13822222222',
        manageUserType: 1,
        manageUserTypeName: '普通员工',
        job: '部门总监',
        isAllControl: true,
        updateDate: '2022/08/11',
        status: '待激活',
        permanentSpaceName: '上格云',
        oaId: 'sdfsdf',
      },
      {
        userId: '222',
        companyId: '222',
        companyName: '博锐',
        name: '赵男士',
        phone: '1382266622',
        manageUserType: 2,
        manageUserTypeName: '普通员工',
        job: '部门总监',
        isAllControl: false,
        updateDate: '2022/08/11',
        status: '待激活',
        permanentSpaceName: '上格云',
      },
    ]);
    // setIsSyncOa(true);
    queryUserList(paramObj)
      .then((res) => {})
      .catch((err) => {});
    queryCompanyOAById({ companyId: 'xxxx' })
      .then((res) => {})
      .catch((err) => {});
    //查询受控列表
    getControlSpaceCompany()
      .then((res) => {})
      .catch((err) => {});
  }, []);
  const checkPerson = (item) => {
    setPerVisible(true);
    setCheckSign('check'); //设置为查看状态
    debugger;
    setCheckUser(item);
  };
  const editPerson = (item) => {
    setPerVisible(true);
    setCheckSign('edit');
    setCheckUser(item);
  };
  //作废用户
  const invalidPerson = (item) => {};
  //添加临时用户
  const addTemporaryPerson = () => {
    setPerVisible(true);
    setCheckSign('add');
    setCheckUser({});
  };
  const addNewPerson = () => {
    setPerVisible(true);
    setCheckSign('add');
    setCheckUser({});
  };

  return (
    <div className={styles.memberwrap}>
      <PageHeader
        title={<FormattedMessage id="menu.member" />}
        action={
          <div className={styles.headerRight}>
            <Search />
            {isSyncOa ? (
              <>
                <div className={styles.allIn}>已开启OA同步</div>
                <div
                  className={styles.invalid}
                  onClick={() => {
                    goToInvalid();
                  }}
                >
                  已作废
                </div>
                <div className={styles.addButton} onClick={addTemporaryPerson}>
                  添加临时成员
                </div>
              </>
            ) : (
              <>
                <div className={styles.allIn}>批量导入</div>
                <div
                  className={styles.invalid}
                  onClick={() => {
                    goToInvalid();
                  }}
                >
                  已作废
                </div>
                <div className={styles.addButton} onClick={addNewPerson}>
                  新增成员
                </div>
              </>
            )}
          </div>
        }
      />
      <div className={styles.bottomTable}>
        <Table
          columns={getColumns()}
          rowKey="phone"
          dataSource={userList}
          loading={loading}
          page={page}
          total={total}
          pagination={!!userList.length}
          onFilterChange={(key, options) => {
            debugger;
            // if (key == 'spaceName' || key == 'tenantName') {
            //   setShowFilterIds(options);
            // }
          }}
          onRowClick={(record) => {}}
          onSortChange={(col, direction) => {
            debugger;
            // setSorter({ [col['sortIndex']]: direction });
          }}
          onPageChange={(p) => {
            debugger;
            setPage(p);
          }}
        />
        {!userList.length && !loading && <Empty />}
      </div>
      {perVisible && (
        <PersonModal
          checkUser={checkUser}
          checkSign={checkSign}
          onClose={onClose}
          setCheckSign={setCheckSign}
        ></PersonModal>
      )}
    </div>
  );
};

export default Member;
